<?php
// Own namespace
namespace CoreFramework\Registry\Socket;

// Import framework stuff
use CoreFramework\Listener\Listenable;
use CoreFramework\Registry\Registerable;

/**
 * A class for registerable socket classes
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface RegisterableSocket extends Registerable {
	/**
	 * Checks whether given socket resource is registered. If $socketResource is
	 * false only the instance will be checked.
	 *
	 * @param	$infoInstance		An instance of a ShareableInfo class
	 * @param	$socketResource		A valid socket resource
	 * @return	$isRegistered		Whether the given socket resource is registered
	 */
	function isSocketRegistered (ShareableInfo $infoInstance, $socketResource);

	/**
	 * Registeres given socket for listener or throws an exception if it is already registered
	 *
	 * @param	$infoInstance	An instance of a ShareableInfo class
	 * @param	$socketResource		A valid socket resource
	 * @return	void
	 * @throws	SocketAlreadyRegisteredException	If the given socket is already registered
	 */
	function registerSocket (ShareableInfo $infoInstance, $socketResource);

	/**
	 * Getter for given listener's socket resource
	 *
	 * @param	$listenerInstance	An instance of a Listenable class
	 * @return	$socketResource		A valid socket resource
	 * @throws	NoSocketRegisteredException		If the requested socket is not registered
	 */
	function getRegisteredSocketResource (Listenable $listenerInstance);

	/**
	 * "Getter" for info instance from given package data
	 *
	 * @param	$packageData	Raw package data
	 * @return	$infoInstance	An instance of a ShareableInfo class
	 */
	function getInfoInstanceFromPackageData (array $packageData);

}
